@@ -34,7 +34,37 @@
 
  */
 
-void valgrad(double *y, double *Umat, int *myq, int *m, double *x, int *n, int *nbeta, double *beta, double *z, double *Dinvfornu, double *logdetDinvfornu, int *family_glmm, double *Dstarinv, double *logdetDstarinv, double *ustar, double *Sigmuhinv, double *logdetSigmuhinv, double *pee, int *nps, int *T, int *nrandom, int *meow, double *nu, int *zeta, double *tconst, double *v, int *ntrials, double *value, double *gradient, double *b, double *wts)
+void valgrad(double *y, 
+double *Umat, 
+int *myq, 
+int *m, 
+double *x, 
+int *n, 
+int *nbeta, 
+double *beta, 
+double *z, 
+double *Dinvfornu, 
+double *logdetDinvfornu, 
+int *family_glmm, 
+double *Dstarinv, 
+double *logdetDstarinv, 
+double *ustar, 
+double *Sigmuhinv, 
+double *logdetSigmuhinv, 
+double *pee, 
+int *nps, 
+int *T, 
+int *nrandom, 
+int *meow, 
+double *nu, 
+int *zeta, 
+double *tconst, 
+double *v, 
+int *ntrials, 
+double *value, 
+double *gradient, 
+double *b, 
+double *wts)
 {
     double *Uk = Calloc(*myq, double);
     
